@@ -9,7 +9,13 @@ import sys
 
 from loguru import logger
 
-from .exception import (
+from pipecatcloud.agent import (
+    DailySessionArguments,
+    PipecatSessionArguments,
+    SessionArguments,
+    WebSocketSessionArguments,
+)
+from pipecatcloud.exception import (
     AgentNotHealthyError,
     AgentStartError,
     AuthError,
@@ -18,22 +24,27 @@ from .exception import (
     Error,
     InvalidError,
 )
-from .session import Session, SessionParams
+from pipecatcloud.session import Session, SessionParams
 
 logger.remove()
 logger.add(sys.stderr, level=str(os.getenv("PCC_LOG_LEVEL", "INFO")))
 
 
 __all__ = [
+    # Agent classes
+    "DailySessionArguments",
+    "PipecatSessionArguments",
+    "SessionArguments",
+    "WebSocketSessionArguments",
     # Session classes
     "Session",
     "SessionParams",
     # Exception classes
-    "Error",
-    "ConfigFileError",
-    "AuthError",
-    "InvalidError",
-    "ConfigError",
     "AgentNotHealthyError",
     "AgentStartError",
+    "AuthError",
+    "ConfigError",
+    "ConfigFileError",
+    "Error",
+    "InvalidError",
 ]
